# vim: set ts=4 sw=4 et:

# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

%define sourcename mldonkey
%define _prova	 0

Name:           MLDonkey
Summary:        Filesharing client for eDonkey 2000 and other P2P systems
Version:        3.1.3
Release:        1.1
License:        Other License(s), see package, GPL-2.0+
Group:          Productivity/Networking/Other
URL:            http://mldonkey.sourceforge.net/Main_Page
Source:         http://prdownloads.sourceforge.net/mldonkey/mldonkey-%{version}.tar.bz2
Patch1:         mldonkey-disable-asm-opt.patch
Patch2:         mldonkey-link_against_libpng.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires:  gcc gcc-c++ perl wget qt3-devel
BuildRequires:  ocaml camlp4 zlib-devel librsvg-devel lablgtk2-devel
BuildRequires:  gtk2-devel >= 2.4.0
BuildRequires:  zlib-devel
%if %suse_version > 1020
BuildRequires:  libbz2-devel
%endif
%if %suse_version == 1010
BuildRequires:  avahi-compat-mDNSResponder
%endif
BuildRequires:  gd-devel libpng-devel libjpeg-devel file-devel ncurses-devel
#BuildRequires:  -post-build-checks
Requires:       perl ocaml camlp4 wget gd file
Obsoletes:      MLDonkey-init
Provides:       mldonkey = %{version}

%description
mldonkey is a peer-to-peer filesharing client originally developed for
use with the eDonkey system that also supports Limewire, OpenNap,
AudioGalaxy and other P2P systems. The actual client and the user
interface are completely separated and can thus be executed on
different machines. A web interface is available as well.

%package gui 
Summary:        Gtk2 GUI for mldonkey
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}

%description gui 
mldonkey gtk2 GUI for mldonkey.
This is the "new gui 2"

%if "%{_prova}" == "1"
%package init
Summary:        Init to launch mldonkey
Group:          Productivity/Networking/Other
Requires:       %{name} = %{version}
PreReq:         pwdutils

%description init
This package contains init to launch mldonkey as a service

%package ed2k_submit
Summary:        This tool gives you an easy way to add a ed2k-link
Group:          Productivity/Networking/Other
Requires:       perl-libwww-perl

%description ed2k_submit
This tool gives you an easy way to add a ed2k-link 
(like ed2k://|file|filename.exe|21352658|72b0b287cab7d875ccc1d89ebe910b9g|) 
with a single click to your mldonkey download queue.

You need to edit /etc/sysconfig/mldonkey_submit
%endif

%prep
%setup -q -n %{sourcename}-%{version}
%patch1 -p1
%patch2

%build
caml_version="$(rpm -q --qf='%{VERSION}\n' ocaml)"

%configure \
    --disable-option-checking \
    --enable-gnutella \
    --enable-gnutella2 \
    --enable-gui=newgui2 \
    --enable-checks \
    --disable-rpath \
    --enable-ocamlver="$caml_version"

%__make %{?_smp_mflags}
%__make utils

%install
%makeinstall

# core
install -m 755  distrib/mldonkey_command %{buildroot}%{_bindir}/mldonkey_command
install -m 755  distrib/kill_mldonkey %{buildroot}%{_bindir}/kill_mldonkey
install -m 755  make_torrent %{buildroot}%{_bindir}/make_torrent
install -m 755  mld_hash %{buildroot}%{_bindir}/mld_hash

%if "%{_prova}" == "1"
# init 
install -d -m 755 %{buildroot}%{_initrddir}
install -d -m 755 %{buildroot}/var/lib/mldonkey
install -d -m 755 %{buildroot}/var/cache/mldonkey
install -d -m 755 %{buildroot}/var/lib/mldonkey/incoming
install -d -m 755 %{buildroot}%{_sysconfdir}/sysconfig
install -m 755 packages/rpm/mldonkey.init %{buildroot}%{_initrddir}/mldonkey
install -m 644 packages/rpm/mldonkey.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/mldonkey

# ed2k_submit
install -d -m 755 %{buildroot}%{_datadir}/services/
install -m 755 distrib/ed2k_submit/mldonkey_submit %{buildroot}%{_bindir}/mldonkey_submit
install -m 644 distrib/ed2k_submit/mldonkey %{buildroot}%{_sysconfdir}/sysconfig/mldonkey_submit
install -m 644 distrib/ed2k_submit/ed2k.protocol  %{buildroot}%{_datadir}/services/ed2k.protocol
%endif

%if "%{_prova}" == "1"
%pre init
useradd mldonkey

%postun init
userdel mldonkey
%endif

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files
%defattr(-,root,root)
%doc ChangeLog Copying.txt
%{_bindir}/mlnet
%{_bindir}/mldonkey_command
%{_bindir}/kill_mldonkey
%{_bindir}/mlbt
%{_bindir}/mldc
%{_bindir}/mldonkey
%{_bindir}/mlgnut
%{_bindir}/mlslsk
%{_bindir}/make_torrent
%{_bindir}/mld_hash

%files gui
%defattr(-,root,root)
%{_bindir}/*gui

%if "%{_prova}" == "1"
%files init
%defattr(-,root,root)
%doc Copying.txt
%config(noreplace) %{_sysconfdir}/sysconfig/mldonkey
%config(noreplace) %{_initrddir}/mldonkey
%attr(700,mldonkey,mldonkey) %dir /var/lib/mldonkey/incoming
%attr(700,mldonkey,mldonkey) %dir /var/cache/mldonkey
%attr(700,mldonkey,mldonkey) %dir /var/lib/mldonkey

%files ed2k_submit
%defattr(-,root,root)
%doc Copying.txt
%config(noreplace) %{_sysconfdir}/sysconfig/mldonkey_submit
%{_bindir}/mldonkey_submit
%{_datadir}/services/ed2k.protocol
%endif

%changelog
* Thu Aug 23 2012 seife+obs@b1-systems.com
- update to 3.1.3
- remove mldonkey-fix_missing_return_in_non_void_functions.patch,
  instead just remove pentium asm optimization
  * note: the code the compiler complains about is probably
    correct albeit obscure (asm code that puts the return code
    onto the stack), the easiest fix is to disable it.
* Thu Aug 16 2012 seife+obs@b1-systems.com
- fix build for 12.2 (add --disable-option-checking to configure)
* Tue May 29 2012 pascal.bleser@opensuse.org
- update to 3.1.2:
  * minor fixes
* Sat Apr 14 2012 pascal.bleser@opensuse.org
- update to 3.1.1:
  * update options description of allow_local_network
  * DC: show hashing progress in dcinfo
  * DC: fix ownership for downloads by non-admin users
  * less allocations
* Sun Jan  1 2012 pascal.bleser@opensuse.org
- update to 3.1.0:
  * BT/DHT: fix logging in tools/bt_dht_node.ml
  * http: better error reporting
  * BT: better UI for subfile selection
  * do not reload page when toggling subfiles
  * http: fix XSS in error handler
  * BT/DHT: show stats, choose random port
  * options: disable Overnet by default and remove contact.dat from web_infos
  * mail: multiple mail addresses for admin
  * diskinfo: recognize BTRFS
  * BT/DHT: fix logging
  * BT/DHT: make token more robust against broken nodes
  * HTML: mark not saved values in options
  * BT: stop asking users to submit unknown client ids
  * GTK2 GUI: fix too obtrusive splash window
  * BT: open DHT port by UPnP
  * BT: support for partial download
  * partial files are not committed, location in temp dir is shown so that
    users can easily locate downloaded subfiles
  * BT: DHT support
  - new options BT-dht_port, BT-use_trackers, BT-dht_bootstrap_nodes
  - new verbosity level "dht"
* Sun Jan  1 2012 pascal.bleser@opensuse.org
- add mldonkey-link_against_libpng.patch to fix build on >= 12.1, as upstream
  forgot to link against libpng when using libgd
* Sun Mar 13 2011 pascal.bleser@opensuse.org
- update to 3.0.7
* Fri May  7 2010 andrea@links2linux.de
- new upstream version 3.0.2
- enable newgui2
- removed unused buildrequires
* Sat Mar  7 2009 andrea@links2linux.de
- new upstream version 3.0.0
* Wed Feb 18 2009 andrea@linsk2linux.de
- update to version 2.9.7
* Sat Aug  9 2008 andrea@linsk2linux.de
- update to version 2.9.6
* Fri May 23 2008 andrea@linsk2linux.de
- update to version 2.9.5
* Thu Mar 20 2008 andrea@linsk2linux.de
- found how to compile mldonkey-tools, no more required bynaries.
- added package "init" and "ed2k_submit"
* Tue Mar 18 2008 andrea@linsk2linux.de
- update to version 2.9.4
* Sat Dec 29 2007 andrea@linsk2linux.de
- update to version 2.9.2
- mldonkey-tools added for 64 bit too
* Sat Dec  9 2006 henne@links2linux.de
- update to version 2.8.2
- add mldonkey-tools
- put the gtk2 gui into subpackage
* Thu Jun 22 2006 henne@links2linux.de
- update to version 2.7.7
* Thu Apr 13 2006 henne@links2linux.de
- update to version 2.7.5
* Sun Nov 20 2005 henne@links2linux.de
- update to version 2.7.0
- switch to static binary source packages
* Mon May 17 2004 henne@links2linux.de
- update to version 2.5.21
* Mon Feb 23 2004 henne@links2linux.de
- update to version 2.5.12 which has p2p guardian support
* Fri Feb 20 2004 henne@links2linux.de
- dont use mkdir -p in the wrapper script.
* Thu Feb 12 2004 henne@links2linux.de
- update to version 2.5.11
- add utils
- specfile cleanup
- added a wrapper script to work around the problem when
  the binarys resides in a directory where ordinary users have no
  write permissions and the binary wants to write config files
  there.
* Sat Aug 16 2003 henne@links2linux.de
- add desktop file
* Tue Jul  1 2003 henne@links2linux.de
- Update to 2.05-3
* Sat Apr 19 2003 henne@links2linux.de
- update to version 2.04rc1
* Mon Feb 10 2003 henne@links2linux.de
- Fix configure.in to properly report a non existing ocamlopt.
* Fri Jan 31 2003 henne@links2linux.de
- update to 2.02
* Wed Oct 16 2002 henne@links2linux.de
- update -> 2.00 (final release)
* Tue Sep 17 2002 henne@links2linux.de
- initial package
